@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.33";
+our $VERSION = "2.3301";
 
 use Data::Dumper;
 {
@@ -454,8 +454,8 @@ sub fold {
     if ($word_char_re
 	and my($w2) = /\A( (?: ${word_char_re} \cH ? ) + )/x
 	and my($lead, $w1) = $folded =~ m{
-		\A ## avoid CSI final char making a word
-		   ( (?: [^\e]* ${csi_re}++ ) *+ .*? )
+		\A ## avoid CSI/OSC final char making a word
+		   ( (?: [^\e]* (?:${csi_re}|${osc_re})++ ) *+ .*? )
 		   ( (?: ${word_char_re} \cH ? ) + )
 		\z }x
     ) {
@@ -629,7 +629,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.33
+Version 2.3301
 
 =head1 SYNOPSIS
 
